crikit.ui.utils package — CRIKit2 0.4.3 documentation

# crikit.ui.utils package

## Submodules

## crikit.ui.utils.check_requirements module

crikit.ui.utils.check_requirements.check_requirements()

  Check that all necessary libraries are installed and to the correct version

## crikit.ui.utils.roi module

### Visualization General Utilities (crikit.ui.visgentuils)

> roimask : Create a region-of-interest binary mask

crikit.ui.utils.roi.roimask(imgx, imgy, xvec, yvec)

  Create a region-of-interest binary mask from vertices.

  Parameters

    - imgx (ndarray) – X-axis vector in physical units

    - imgy (ndarray) – Y-axis vector in physical units

    - xvec (ndarray) – Vector of x-locations of selected points

    - yvec (ndarray) – Vector of y-locations of selected points

  Returns

    - mask (ndarray) – Binary mask

    - path (MPL path object) – Matplotlib path object describing ROI

## Module contents

### CRI Spectral Processing Tools (CRIkit)